@@ -7,7 +7,7 @@ Rcpp::EvalBase *gev = NULL;                  // pointer to abstract base class
 
 typedef void (*S2_fp) (int *, int *, double *, double *, double *, int *, float *, double *);
 extern "C" void n1qn1_ (S2_fp simul, int n[], double x[], double f[], double g[], double var[], double eps[],
-                        int mode[], int niter[], int nsim[], int imp[], int lp[], double zm[], int izs[], float rzs[], double dzs[]);
+                        int mode[], int niter[], int nsim[], int imp[], double zm[], int izs[], float rzs[], double dzs[]);
 
 unsigned int n1qn1_calls = 0, n1qn1_grads = 0;
 int n1qn1_fprint = 0;
@@ -66,7 +66,7 @@ n1qn1_wrap(
     gev = new Rcpp::EvalStandard(gSEXP, rhoSEXP); // Standard evaulation
   }
   
-  int n, mode, niter, nsim, imp, lp=6, nzm;
+  int n, mode, niter, nsim, imp, nzm;
   n = INTEGER(nSEXP)[0];
   mode = INTEGER(modeSEXP)[0];
   niter = INTEGER(niterSEXP)[0];
@@ -87,7 +87,7 @@ n1qn1_wrap(
   std::fill(&var[0], &var[0]+n, 0.1);
   
   n1qn1_(fwrap,&n,x,&f,g,var,&eps,
-         &mode,&niter,&nsim,&imp,&lp,zm,izs,rzs,dzs);
+         &mode,&niter,&nsim,&imp,zm,izs,rzs,dzs);
         
   Rcpp::NumericVector par(n);
   std::copy(&x[0],&x[0]+n,&par[0]);
